# Speaker Basics

The purpose of a speaker is simple — to make sounds. Speakers exist all around us — in phones, TVs, radios, greeting cards, toys, musical keyboards, and video games. Some speakers are amplified — they take sounds and use special components to make the sounds louder. For example, electric megaphones, PA (public announcement) systems in schools and buildings, and loudspeakers at concerts. These speakers can also play recorded sounds, or even create new made up sounds that you'd never hear in nature.

Speakers work by converting electrical energy into mechanical energy. That is, changes in the voltage/current in a circuit cause something physical to move back and forth, which generates a sound. As we talked about in , electricity and magnetism are two closely related concepts. In an electric motor, current flowing through a loop of wire will push on a nearby magnet. This pushing force is felt equally by both the magnet and the loop of wire, and causes them to move apart. A speaker uses this property to move and vibrate the cone of the speaker (the frontmost part that you see), which in turn vibrates the surrounding air.

# Sound Waves

As the speaker vibrates, the air around it vibrates as well, and travels outward from the speaker in all directions. When the vibrations travel into your ear, you are able to sense the vibrations as sounds.

The vibrations that create sounds move back and forth at different speeds (frequencies). The faster the vibrations move, the higher the frequency, or pitch, that you hear. Likewise, slower vibrations make lower frequency sounds. Because larger, more massive objects tend to move slower, they also tend to make lower frequency sounds. And, smaller, lighter objects tend to make higher frequency sounds.

For example, if you take a glass partially filled with water, and gently tap it with a spoon, the glass will ring. If you add more water, and tap it again, the glass will ring at a lower frequency. The more water you add, the more massive the glass and water become, and therefore the slower it can vibrate. Slower vibrations mean lower frequencies.

Sounds and music are composed of a continuous blend of many different frequencies that you hear at the same time. It is the combination of sound waves vibrating at different frequencies that create all of the familiar (and distinct) sounds you know, from trumpets and violins, to chalk scratching a blackboard.

The CREATOR Kit includes a small speaker; small speakers tend to be better for higher frequency sounds than lower frequency sounds. Also, the CREATOR Kit's speaker is unamplified — this means that the sounds it produces will be at a relatively low volume. If you are using the kit in a noisy environment, we recommend using earphones or computer speakers plugged into the audio jack instead.